@@ -72,6 +72,7 @@ typedef enum
 	FreeRDP_IPv6Enabled = 768,
 	FreeRDP_AutoReconnectionEnabled = 832,
 	FreeRDP_PrintReconnectCookie = 836,
+	FreeRDP_AutoReconnectionPacketSupported = 837,
 	FreeRDP_DynamicDaylightTimeDisabled = 898,
 	FreeRDP_AllowFontSmoothing = 961,
 	FreeRDP_DisableWallpaper = 962,
@@ -138,6 +139,7 @@ typedef enum
 	FreeRDP_TransportDump = 1860,
 	FreeRDP_TransportDumpReplay = 1862,
 	FreeRDP_DeactivateClientDecoding = 1863,
+	FreeRDP_TransportDumpReplayNodelay = 1864,
 	FreeRDP_GatewayUseSameCredentials = 1991,
 	FreeRDP_GatewayEnabled = 1992,
 	FreeRDP_GatewayBypassLocal = 1993,
@@ -197,6 +199,7 @@ typedef enum
 	FreeRDP_GfxSendQoeAck = 3846,
 	FreeRDP_GfxAVC444v2 = 3847,
 	FreeRDP_GfxPlanar = 3849,
+	FreeRDP_GfxSuspendFrameAck = 3850,
 	FreeRDP_DrawNineGridEnabled = 3968,
 	FreeRDP_DrawGdiPlusEnabled = 4032,
 	FreeRDP_DrawGdiPlusCacheEnabled = 4033,
@@ -366,6 +369,7 @@ typedef enum
 	FreeRDP_DrawNineGridCacheEntries = 3970,
 	FreeRDP_DeviceCount = 4161,
 	FreeRDP_DeviceArraySize = 4162,
+	FreeRDP_ForceIPvX = 4675,
 	FreeRDP_ClipboardFeatureMask = 4801,
 	FreeRDP_StaticChannelCount = 4928,
 	FreeRDP_StaticChannelArraySize = 4929,
